@@ -18,13 +18,15 @@
 //! This module contains a query optimizer that operates against a logical plan and applies
 //! some simple rules to a logical plan, such as "Projection Push Down" and "Type Coercion".
 
-pub mod aggregate_statistics;
-pub mod constant_folding;
+#![allow(clippy::module_inception)]
+pub mod common_subexpr_eliminate;
+pub mod eliminate_filter;
 pub mod eliminate_limit;
 pub mod filter_push_down;
-pub mod hash_build_probe_order;
 pub mod limit_push_down;
 pub mod optimizer;
 pub mod projection_push_down;
 pub mod simplify_expressions;
+pub mod single_distinct_to_groupby;
+pub mod subquery_filter_to_join;
 pub mod utils;
